@@ -5,6 +5,7 @@ use strictures 2;
 use autodie;
 
 use version;
+use Path::Iterator::Rule;
 use Path::Tiny;
 use Fcntl qw/:seek/;
 use Encode;
@@ -28,11 +29,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.22
+Version v3.0.23
 
 =cut
 
-our $VERSION = version->declare("v3.0.22");
+our $VERSION = version->declare("v3.0.23");
 
 =head1 SYNOPSIS
 
@@ -174,40 +175,27 @@ sub find
 {
 	my ( $self, @paths ) = @_;
 
-	my @files       = ();
-	my $paths_count = @paths;
+	my $rule    = Path::Iterator::Rule->new;
+	my %options = (
+		follow_symlinks => 0,
+	);
 
-	foreach (@paths) {
-		my $path = path($_);
+	$rule->max_depth(1)
+		unless $self->recursive;
+	$rule->not_name( $self->ignore_regex );
+	$rule->file->nonempty;
 
-		if ( $path->is_dir ) {
-			$path->visit(
-				sub {
-					# Silently skip empty files or ignored files
-					return if -z $_ or $_ =~ $self->ignore_regex;
-					if ( $_ =~ $self->check_regex ) {
-						push @files, $_;
-					}
-					else {
-						warn "skipped file $_\n" if $self->skipped;
-					}
-				},
-				{ recurse => $self->recursive }
-			);
-		}
-		elsif ( $path =~ $self->ignore_regex ) {
-
-			# Silently skip ignored files
-			next;
-		}
-		elsif ( $paths_count == 1 or $path =~ $self->check_regex ) {
-			push @files, $path;
-		}
-		else {
-			warn "skipped file $path\n" if $self->skipped;
+	if ( @paths >> 1 ) {
+		if ( $self->skipped ) {
+			my $skipped = $rule->clone->not_name( $self->check_regex );
+			for ( $skipped->all( @paths, \%options ) ) {
+				warn "skipped file $_\n";
+			}
 		}
+		$rule->name( $self->check_regex );
 	}
-	return @files;
+
+	return $rule->all( @paths, \%options );
 }
 
 sub parse
